package com.gree.mall.manager.logic.policy;

import cn.hutool.db.sql.Order;
import com.gree.mall.manager.enums.ExamineWorkerStatusEnum;
import com.gree.mall.manager.enums.OrderStatusEnum;
import com.gree.mall.manager.enums.workorder.OrderBaseStatusEnum;
import com.gree.mall.manager.exception.RemoteServiceException;
import com.gree.mall.manager.plus.entity.PgOrderBase;
import com.gree.mall.manager.plus.entity.WebsitUser;
import com.gree.mall.manager.plus.service.PgOrderBaseService;
import com.gree.mall.manager.plus.service.WebsitUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class WorkerManagerLogic {

    @Autowired
    WebsitUserService websitUserService;

    @Autowired
    PgOrderBaseService pgOrderBaseService;


    public void stop(String id) {

        WebsitUser websitUserBean = websitUserService.getById(id);
        if (!websitUserBean.getExamineStatus().equals(ExamineWorkerStatusEnum.OK.getKey()))
            throw new RemoteServiceException("师傅不处于审核通过");

        WebsitUser websitUser = new WebsitUser();
        websitUser.setId(id);
        websitUser.setExamineStatus(ExamineWorkerStatusEnum.STOP.getKey());
        websitUser.updateById();
    }

    public void activation(String id) {

        WebsitUser websitUserBean = websitUserService.getById(id);
        if (!websitUserBean.getExamineStatus().equals(ExamineWorkerStatusEnum.STOP.getKey()))
            throw new RemoteServiceException("师傅不处于暂停状态");

        WebsitUser websitUser = new WebsitUser();
        websitUser.setId(id);
        websitUser.setExamineStatus(ExamineWorkerStatusEnum.POLICY_WAIT.getKey());
        websitUser.updateById();
    }

    public void quit(String id) {

        WebsitUser websitUserBean = websitUserService.getById(id);
        if (!websitUserBean.getExamineStatus().equals(ExamineWorkerStatusEnum.OK.getKey()))
            throw new RemoteServiceException("师傅不处于审核通过");


        if (pgOrderBaseService.lambdaQuery()
                .and(item -> item.eq(PgOrderBase::getWorkerId,websitUserBean.getUserId()).or().like(PgOrderBase::getWorkerIdList,websitUserBean.getUserId()))
                .eq(PgOrderBase::getWebsitId,websitUserBean.getWebsitId())
                .notIn(PgOrderBase::getOrderStatus, OrderBaseStatusEnum.YQX.getKey(),OrderBaseStatusEnum.YJS.getKey(),
                        OrderBaseStatusEnum.YWG.getKey(),OrderBaseStatusEnum.FWQX.getKey(),OrderBaseStatusEnum.YWGO.getKey(),
                        OrderBaseStatusEnum.YGBGD.getKey(),OrderBaseStatusEnum.FGFZF.getKey(),OrderBaseStatusEnum.YZFGD.getKey(),
                        OrderBaseStatusEnum.FZXBWG.getKey(),OrderBaseStatusEnum.FBBWG.getKey(),OrderBaseStatusEnum.LSXX.getKey(),
                        OrderBaseStatusEnum.PLGB.getKey(),OrderBaseStatusEnum.ZCGB.getKey()
                        ).count() > 1) {

            throw new RemoteServiceException("师傅存在未完工工单，请改派后再离职");
        }


        WebsitUser websitUser = new WebsitUser();
        websitUser.setId(id);
        websitUser.setExamineStatus(ExamineWorkerStatusEnum.QUIT.getKey());
        websitUser.updateById();
    }

    public void againQuit(String id) {

        WebsitUser websitUserBean = websitUserService.getById(id);
        if (!websitUserBean.getExamineStatus().equals(ExamineWorkerStatusEnum.QUIT.getKey()))
            throw new RemoteServiceException("师傅不处于离职状态");

        WebsitUser websitUser = new WebsitUser();
        websitUser.setId(id);
        websitUser.setExamineStatus(ExamineWorkerStatusEnum.POLICY_WAIT.getKey());
        websitUser.updateById();
    }
}
